sqlobject.classregistry module — SQLObject 3.9.1 documentation

# sqlobject.classregistry module

classresolver.py

  2 February 2004, Ian Bicking <ianb@colorstudy.com>

Resolves strings to classes, and runs callbacks when referenced classes are created.

Classes are referred to only by name, not by module. So that identically-named classes can coexist, classes are put into individual registries, which are keyed on strings (names). These registries are created on demand.

Use like:

    >>> import classregistry
    >>> registry = classregistry.registry('MyModules')
    >>> def afterMyClassExists(cls):
    ...    print('Class finally exists: %s' % cls)
    >>> registry.addClassCallback('MyClass', afterMyClassExists)
    >>> class MyClass:
    ...    pass
    >>> registry.addClass(MyClass)
    Class finally exists: MyClass

class `sqlobject.classregistry.` `ClassRegistry`(name)

  Bases: `object`

  We’ll be dealing with classes that reference each other, so class C1 may reference C2 (in a join), while C2 references C1 right back. Since classes are created in an order, there will be a point when C1 exists but C2 doesn’t. So we deal with classes by name, and after each class is created we try to fix up any references by replacing the names with actual classes.

  Here we keep a dictionaries of class names to classes – note that the classes might be spread among different modules, so since we pile them together names need to be globally unique, to just module unique. Like needSet below, the container dictionary is keyed by the class registry.

  `addCallback`(callback, *args, **kw)

    This callback is called for all classes, not just specific ones (like addClassCallback).

  `addClass`(cls)

    Everytime a class is created, we add it to the registry, so that other classes can find it by name. We also call any callbacks that are waiting for the class.

  `addClassCallback`(className, callback, *args, **kw)

    Whenever a name is substituted for the class, you can register a callback that will be called when the needed class is created. If it’s already been created, the callback will be called immediately.

  `allClasses`()
  `getClass`(className)

`sqlobject.classregistry.` `findClass`(name, class_registry=None)

`sqlobject.classregistry.` `registry`(item)